// This file is safe to edit. Once it exists it will not be overwritten

package restapi

import (
	"crypto/tls"
	"net/http"

	"github.com/go-openapi/errors"
	"github.com/go-openapi/runtime"
	"github.com/go-openapi/runtime/middleware"

	"code.fbi.h-da.de/cocsn/cocsn-api/api/restapi/operations"
	"code.fbi.h-da.de/cocsn/cocsn-api/api/restapi/operations/data"
	"code.fbi.h-da.de/cocsn/cocsn-api/api/restapi/operations/operationsops"
	"code.fbi.h-da.de/cocsn/cocsn-api/api/restapi/operations/root"
	"code.fbi.h-da.de/cocsn/cocsn-api/api/restapi/operations/yang_library_version"
)

//go:generate swagger generate server --target ../../api --name Cocsn --spec ../../cocsn.json --principal interface{}

func configureFlags(api *operations.CocsnAPI) {
	// api.CommandLineOptionsGroups = []swag.CommandLineOptionsGroup{ ... }
}

func configureAPI(api *operations.CocsnAPI) http.Handler {
	// configure the api here
	api.ServeError = errors.ServeError

	// Set your custom logger if needed. Default one is log.Printf
	// Expected interface func(string, ...interface{})
	//
	// Example:
	// api.Logger = log.Printf

	api.UseSwaggerUI()
	// To continue using redoc as your UI, uncomment the following line
	// api.UseRedoc()

	api.JSONConsumer = runtime.JSONConsumer()

	api.JSONProducer = runtime.JSONProducer()

	// Applies when the Authorization header is set with the Basic scheme
	if api.BasicAuthAuth == nil {
		api.BasicAuthAuth = func(user string, pass string) (interface{}, error) {
			return nil, errors.NotImplemented("basic auth  (basicAuth) has not yet been implemented")
		}
	}

	// Set your custom authorizer if needed. Default one is security.Authorized()
	// Expected interface runtime.Authorizer
	//
	// Example:
	// api.APIAuthorizer = security.Authorized()
	if api.DataDataCocsnArpTableArpEntryArpEntryAddressAddressGetHandler == nil {
		api.DataDataCocsnArpTableArpEntryArpEntryAddressAddressGetHandler = data.DataCocsnArpTableArpEntryArpEntryAddressAddressGetHandlerFunc(func(params data.DataCocsnArpTableArpEntryArpEntryAddressAddressGetParams, principal interface{}) middleware.Responder {
			return middleware.NotImplemented("operation data.DataCocsnArpTableArpEntryArpEntryAddressAddressGet has not yet been implemented")
		})
	}
	if api.DataDataCocsnArpTableArpEntryArpEntryAddressGetHandler == nil {
		api.DataDataCocsnArpTableArpEntryArpEntryAddressGetHandler = data.DataCocsnArpTableArpEntryArpEntryAddressGetHandlerFunc(func(params data.DataCocsnArpTableArpEntryArpEntryAddressGetParams, principal interface{}) middleware.Responder {
			return middleware.NotImplemented("operation data.DataCocsnArpTableArpEntryArpEntryAddressGet has not yet been implemented")
		})
	}
	if api.DataDataCocsnArpTableArpEntryArpEntryAddressInterfaceGetHandler == nil {
		api.DataDataCocsnArpTableArpEntryArpEntryAddressInterfaceGetHandler = data.DataCocsnArpTableArpEntryArpEntryAddressInterfaceGetHandlerFunc(func(params data.DataCocsnArpTableArpEntryArpEntryAddressInterfaceGetParams, principal interface{}) middleware.Responder {
			return middleware.NotImplemented("operation data.DataCocsnArpTableArpEntryArpEntryAddressInterfaceGet has not yet been implemented")
		})
	}
	if api.DataDataCocsnArpTableArpEntryArpEntryAddressPhsAddressGetHandler == nil {
		api.DataDataCocsnArpTableArpEntryArpEntryAddressPhsAddressGetHandler = data.DataCocsnArpTableArpEntryArpEntryAddressPhsAddressGetHandlerFunc(func(params data.DataCocsnArpTableArpEntryArpEntryAddressPhsAddressGetParams, principal interface{}) middleware.Responder {
			return middleware.NotImplemented("operation data.DataCocsnArpTableArpEntryArpEntryAddressPhsAddressGet has not yet been implemented")
		})
	}
	if api.DataDataCocsnArpTableArpEntryGetHandler == nil {
		api.DataDataCocsnArpTableArpEntryGetHandler = data.DataCocsnArpTableArpEntryGetHandlerFunc(func(params data.DataCocsnArpTableArpEntryGetParams, principal interface{}) middleware.Responder {
			return middleware.NotImplemented("operation data.DataCocsnArpTableArpEntryGet has not yet been implemented")
		})
	}
	if api.DataDataCocsnArpTableDeleteHandler == nil {
		api.DataDataCocsnArpTableDeleteHandler = data.DataCocsnArpTableDeleteHandlerFunc(func(params data.DataCocsnArpTableDeleteParams, principal interface{}) middleware.Responder {
			return middleware.NotImplemented("operation data.DataCocsnArpTableDelete has not yet been implemented")
		})
	}
	if api.DataDataCocsnArpTableGetHandler == nil {
		api.DataDataCocsnArpTableGetHandler = data.DataCocsnArpTableGetHandlerFunc(func(params data.DataCocsnArpTableGetParams, principal interface{}) middleware.Responder {
			return middleware.NotImplemented("operation data.DataCocsnArpTableGet has not yet been implemented")
		})
	}
	if api.DataDataCocsnArpTablePatchHandler == nil {
		api.DataDataCocsnArpTablePatchHandler = data.DataCocsnArpTablePatchHandlerFunc(func(params data.DataCocsnArpTablePatchParams, principal interface{}) middleware.Responder {
			return middleware.NotImplemented("operation data.DataCocsnArpTablePatch has not yet been implemented")
		})
	}
	if api.DataDataCocsnArpTablePostHandler == nil {
		api.DataDataCocsnArpTablePostHandler = data.DataCocsnArpTablePostHandlerFunc(func(params data.DataCocsnArpTablePostParams, principal interface{}) middleware.Responder {
			return middleware.NotImplemented("operation data.DataCocsnArpTablePost has not yet been implemented")
		})
	}
	if api.DataDataCocsnArpTablePutHandler == nil {
		api.DataDataCocsnArpTablePutHandler = data.DataCocsnArpTablePutHandlerFunc(func(params data.DataCocsnArpTablePutParams, principal interface{}) middleware.Responder {
			return middleware.NotImplemented("operation data.DataCocsnArpTablePut has not yet been implemented")
		})
	}
	if api.DataDataCocsnInterfacesDeleteHandler == nil {
		api.DataDataCocsnInterfacesDeleteHandler = data.DataCocsnInterfacesDeleteHandlerFunc(func(params data.DataCocsnInterfacesDeleteParams, principal interface{}) middleware.Responder {
			return middleware.NotImplemented("operation data.DataCocsnInterfacesDelete has not yet been implemented")
		})
	}
	if api.DataDataCocsnInterfacesGetHandler == nil {
		api.DataDataCocsnInterfacesGetHandler = data.DataCocsnInterfacesGetHandlerFunc(func(params data.DataCocsnInterfacesGetParams, principal interface{}) middleware.Responder {
			return middleware.NotImplemented("operation data.DataCocsnInterfacesGet has not yet been implemented")
		})
	}
	if api.DataDataCocsnInterfacesInterfaceGetHandler == nil {
		api.DataDataCocsnInterfacesInterfaceGetHandler = data.DataCocsnInterfacesInterfaceGetHandlerFunc(func(params data.DataCocsnInterfacesInterfaceGetParams, principal interface{}) middleware.Responder {
			return middleware.NotImplemented("operation data.DataCocsnInterfacesInterfaceGet has not yet been implemented")
		})
	}
	if api.DataDataCocsnInterfacesInterfaceInterfaceNameAddressesAddressesIDGetHandler == nil {
		api.DataDataCocsnInterfacesInterfaceInterfaceNameAddressesAddressesIDGetHandler = data.DataCocsnInterfacesInterfaceInterfaceNameAddressesAddressesIDGetHandlerFunc(func(params data.DataCocsnInterfacesInterfaceInterfaceNameAddressesAddressesIDGetParams, principal interface{}) middleware.Responder {
			return middleware.NotImplemented("operation data.DataCocsnInterfacesInterfaceInterfaceNameAddressesAddressesIDGet has not yet been implemented")
		})
	}
	if api.DataDataCocsnInterfacesInterfaceInterfaceNameAddressesGetHandler == nil {
		api.DataDataCocsnInterfacesInterfaceInterfaceNameAddressesGetHandler = data.DataCocsnInterfacesInterfaceInterfaceNameAddressesGetHandlerFunc(func(params data.DataCocsnInterfacesInterfaceInterfaceNameAddressesGetParams, principal interface{}) middleware.Responder {
			return middleware.NotImplemented("operation data.DataCocsnInterfacesInterfaceInterfaceNameAddressesGet has not yet been implemented")
		})
	}
	if api.DataDataCocsnInterfacesInterfaceInterfaceNameEnabledGetHandler == nil {
		api.DataDataCocsnInterfacesInterfaceInterfaceNameEnabledGetHandler = data.DataCocsnInterfacesInterfaceInterfaceNameEnabledGetHandlerFunc(func(params data.DataCocsnInterfacesInterfaceInterfaceNameEnabledGetParams, principal interface{}) middleware.Responder {
			return middleware.NotImplemented("operation data.DataCocsnInterfacesInterfaceInterfaceNameEnabledGet has not yet been implemented")
		})
	}
	if api.DataDataCocsnInterfacesInterfaceInterfaceNameGetHandler == nil {
		api.DataDataCocsnInterfacesInterfaceInterfaceNameGetHandler = data.DataCocsnInterfacesInterfaceInterfaceNameGetHandlerFunc(func(params data.DataCocsnInterfacesInterfaceInterfaceNameGetParams, principal interface{}) middleware.Responder {
			return middleware.NotImplemented("operation data.DataCocsnInterfacesInterfaceInterfaceNameGet has not yet been implemented")
		})
	}
	if api.DataDataCocsnInterfacesInterfaceInterfaceNameNameGetHandler == nil {
		api.DataDataCocsnInterfacesInterfaceInterfaceNameNameGetHandler = data.DataCocsnInterfacesInterfaceInterfaceNameNameGetHandlerFunc(func(params data.DataCocsnInterfacesInterfaceInterfaceNameNameGetParams, principal interface{}) middleware.Responder {
			return middleware.NotImplemented("operation data.DataCocsnInterfacesInterfaceInterfaceNameNameGet has not yet been implemented")
		})
	}
	if api.DataDataCocsnInterfacesInterfaceInterfaceNameOperStatusGetHandler == nil {
		api.DataDataCocsnInterfacesInterfaceInterfaceNameOperStatusGetHandler = data.DataCocsnInterfacesInterfaceInterfaceNameOperStatusGetHandlerFunc(func(params data.DataCocsnInterfacesInterfaceInterfaceNameOperStatusGetParams, principal interface{}) middleware.Responder {
			return middleware.NotImplemented("operation data.DataCocsnInterfacesInterfaceInterfaceNameOperStatusGet has not yet been implemented")
		})
	}
	if api.DataDataCocsnInterfacesInterfaceInterfaceNamePhysAddressGetHandler == nil {
		api.DataDataCocsnInterfacesInterfaceInterfaceNamePhysAddressGetHandler = data.DataCocsnInterfacesInterfaceInterfaceNamePhysAddressGetHandlerFunc(func(params data.DataCocsnInterfacesInterfaceInterfaceNamePhysAddressGetParams, principal interface{}) middleware.Responder {
			return middleware.NotImplemented("operation data.DataCocsnInterfacesInterfaceInterfaceNamePhysAddressGet has not yet been implemented")
		})
	}
	if api.DataDataCocsnInterfacesPatchHandler == nil {
		api.DataDataCocsnInterfacesPatchHandler = data.DataCocsnInterfacesPatchHandlerFunc(func(params data.DataCocsnInterfacesPatchParams, principal interface{}) middleware.Responder {
			return middleware.NotImplemented("operation data.DataCocsnInterfacesPatch has not yet been implemented")
		})
	}
	if api.DataDataCocsnInterfacesPostHandler == nil {
		api.DataDataCocsnInterfacesPostHandler = data.DataCocsnInterfacesPostHandlerFunc(func(params data.DataCocsnInterfacesPostParams, principal interface{}) middleware.Responder {
			return middleware.NotImplemented("operation data.DataCocsnInterfacesPost has not yet been implemented")
		})
	}
	if api.DataDataCocsnInterfacesPutHandler == nil {
		api.DataDataCocsnInterfacesPutHandler = data.DataCocsnInterfacesPutHandlerFunc(func(params data.DataCocsnInterfacesPutParams, principal interface{}) middleware.Responder {
			return middleware.NotImplemented("operation data.DataCocsnInterfacesPut has not yet been implemented")
		})
	}
	if api.DataDataCocsnRoutesDeleteHandler == nil {
		api.DataDataCocsnRoutesDeleteHandler = data.DataCocsnRoutesDeleteHandlerFunc(func(params data.DataCocsnRoutesDeleteParams, principal interface{}) middleware.Responder {
			return middleware.NotImplemented("operation data.DataCocsnRoutesDelete has not yet been implemented")
		})
	}
	if api.DataDataCocsnRoutesGetHandler == nil {
		api.DataDataCocsnRoutesGetHandler = data.DataCocsnRoutesGetHandlerFunc(func(params data.DataCocsnRoutesGetParams, principal interface{}) middleware.Responder {
			return middleware.NotImplemented("operation data.DataCocsnRoutesGet has not yet been implemented")
		})
	}
	if api.DataDataCocsnRoutesPatchHandler == nil {
		api.DataDataCocsnRoutesPatchHandler = data.DataCocsnRoutesPatchHandlerFunc(func(params data.DataCocsnRoutesPatchParams, principal interface{}) middleware.Responder {
			return middleware.NotImplemented("operation data.DataCocsnRoutesPatch has not yet been implemented")
		})
	}
	if api.DataDataCocsnRoutesPostHandler == nil {
		api.DataDataCocsnRoutesPostHandler = data.DataCocsnRoutesPostHandlerFunc(func(params data.DataCocsnRoutesPostParams, principal interface{}) middleware.Responder {
			return middleware.NotImplemented("operation data.DataCocsnRoutesPost has not yet been implemented")
		})
	}
	if api.DataDataCocsnRoutesPutHandler == nil {
		api.DataDataCocsnRoutesPutHandler = data.DataCocsnRoutesPutHandlerFunc(func(params data.DataCocsnRoutesPutParams, principal interface{}) middleware.Responder {
			return middleware.NotImplemented("operation data.DataCocsnRoutesPut has not yet been implemented")
		})
	}
	if api.DataDataCocsnRoutesRouteGetHandler == nil {
		api.DataDataCocsnRoutesRouteGetHandler = data.DataCocsnRoutesRouteGetHandlerFunc(func(params data.DataCocsnRoutesRouteGetParams, principal interface{}) middleware.Responder {
			return middleware.NotImplemented("operation data.DataCocsnRoutesRouteGet has not yet been implemented")
		})
	}
	if api.DataDataCocsnRoutesRouteRouteDestinationDestinationGetHandler == nil {
		api.DataDataCocsnRoutesRouteRouteDestinationDestinationGetHandler = data.DataCocsnRoutesRouteRouteDestinationDestinationGetHandlerFunc(func(params data.DataCocsnRoutesRouteRouteDestinationDestinationGetParams, principal interface{}) middleware.Responder {
			return middleware.NotImplemented("operation data.DataCocsnRoutesRouteRouteDestinationDestinationGet has not yet been implemented")
		})
	}
	if api.DataDataCocsnRoutesRouteRouteDestinationExpireGetHandler == nil {
		api.DataDataCocsnRoutesRouteRouteDestinationExpireGetHandler = data.DataCocsnRoutesRouteRouteDestinationExpireGetHandlerFunc(func(params data.DataCocsnRoutesRouteRouteDestinationExpireGetParams, principal interface{}) middleware.Responder {
			return middleware.NotImplemented("operation data.DataCocsnRoutesRouteRouteDestinationExpireGet has not yet been implemented")
		})
	}
	if api.DataDataCocsnRoutesRouteRouteDestinationFlagsGetHandler == nil {
		api.DataDataCocsnRoutesRouteRouteDestinationFlagsGetHandler = data.DataCocsnRoutesRouteRouteDestinationFlagsGetHandlerFunc(func(params data.DataCocsnRoutesRouteRouteDestinationFlagsGetParams, principal interface{}) middleware.Responder {
			return middleware.NotImplemented("operation data.DataCocsnRoutesRouteRouteDestinationFlagsGet has not yet been implemented")
		})
	}
	if api.DataDataCocsnRoutesRouteRouteDestinationGatewayGetHandler == nil {
		api.DataDataCocsnRoutesRouteRouteDestinationGatewayGetHandler = data.DataCocsnRoutesRouteRouteDestinationGatewayGetHandlerFunc(func(params data.DataCocsnRoutesRouteRouteDestinationGatewayGetParams, principal interface{}) middleware.Responder {
			return middleware.NotImplemented("operation data.DataCocsnRoutesRouteRouteDestinationGatewayGet has not yet been implemented")
		})
	}
	if api.DataDataCocsnRoutesRouteRouteDestinationGetHandler == nil {
		api.DataDataCocsnRoutesRouteRouteDestinationGetHandler = data.DataCocsnRoutesRouteRouteDestinationGetHandlerFunc(func(params data.DataCocsnRoutesRouteRouteDestinationGetParams, principal interface{}) middleware.Responder {
			return middleware.NotImplemented("operation data.DataCocsnRoutesRouteRouteDestinationGet has not yet been implemented")
		})
	}
	if api.DataDataCocsnRoutesRouteRouteDestinationInterfaceGetHandler == nil {
		api.DataDataCocsnRoutesRouteRouteDestinationInterfaceGetHandler = data.DataCocsnRoutesRouteRouteDestinationInterfaceGetHandlerFunc(func(params data.DataCocsnRoutesRouteRouteDestinationInterfaceGetParams, principal interface{}) middleware.Responder {
			return middleware.NotImplemented("operation data.DataCocsnRoutesRouteRouteDestinationInterfaceGet has not yet been implemented")
		})
	}
	if api.DataDataGetHandler == nil {
		api.DataDataGetHandler = data.DataGetHandlerFunc(func(params data.DataGetParams, principal interface{}) middleware.Responder {
			return middleware.NotImplemented("operation data.DataGet has not yet been implemented")
		})
	}
	if api.DataDataPatchHandler == nil {
		api.DataDataPatchHandler = data.DataPatchHandlerFunc(func(params data.DataPatchParams, principal interface{}) middleware.Responder {
			return middleware.NotImplemented("operation data.DataPatch has not yet been implemented")
		})
	}
	if api.DataDataPostHandler == nil {
		api.DataDataPostHandler = data.DataPostHandlerFunc(func(params data.DataPostParams, principal interface{}) middleware.Responder {
			return middleware.NotImplemented("operation data.DataPost has not yet been implemented")
		})
	}
	if api.DataDataPutHandler == nil {
		api.DataDataPutHandler = data.DataPutHandlerFunc(func(params data.DataPutParams, principal interface{}) middleware.Responder {
			return middleware.NotImplemented("operation data.DataPut has not yet been implemented")
		})
	}
	if api.OperationsopsOperationsGetHandler == nil {
		api.OperationsopsOperationsGetHandler = operationsops.OperationsGetHandlerFunc(func(params operationsops.OperationsGetParams, principal interface{}) middleware.Responder {
			return middleware.NotImplemented("operation operationsops.OperationsGet has not yet been implemented")
		})
	}
	if api.RootRootGetHandler == nil {
		api.RootRootGetHandler = root.RootGetHandlerFunc(func(params root.RootGetParams, principal interface{}) middleware.Responder {
			return middleware.NotImplemented("operation root.RootGet has not yet been implemented")
		})
	}
	if api.YangLibraryVersionYangLibraryVersionGetHandler == nil {
		api.YangLibraryVersionYangLibraryVersionGetHandler = yang_library_version.YangLibraryVersionGetHandlerFunc(func(params yang_library_version.YangLibraryVersionGetParams, principal interface{}) middleware.Responder {
			return middleware.NotImplemented("operation yang_library_version.YangLibraryVersionGet has not yet been implemented")
		})
	}

	api.PreServerShutdown = func() {}

	api.ServerShutdown = func() {}

	return setupGlobalMiddleware(api.Serve(setupMiddlewares))
}

// The TLS configuration before HTTPS server starts.
func configureTLS(tlsConfig *tls.Config) {
	// Make all necessary changes to the TLS configuration here.
}

// As soon as server is initialized but not run yet, this function will be called.
// If you need to modify a config, store server instance to stop it individually later, this is the place.
// This function can be called multiple times, depending on the number of serving schemes.
// scheme value will be set accordingly: "http", "https" or "unix"
func configureServer(s *http.Server, scheme, addr string) {
}

// The middleware configuration is for the handler executors. These do not apply to the swagger.json document.
// The middleware executes after routing but before authentication, binding and validation
func setupMiddlewares(handler http.Handler) http.Handler {
	return handler
}

// The middleware configuration happens before anything, this middleware also applies to serving the swagger.json document.
// So this is a good place to plug in a panic handling middleware, logging and metrics
func setupGlobalMiddleware(handler http.Handler) http.Handler {
	return handler
}
