// This file is safe to edit. Once it exists it will not be overwritten

package restapi

import (
	"crypto/tls"
	"net/http"

	"github.com/go-openapi/errors"
	"github.com/go-openapi/runtime"
	"github.com/go-openapi/runtime/middleware"

	"code.fbi.h-da.de/cocsn/cocsn-api/waveserver/restapi/operations"
	"code.fbi.h-da.de/cocsn/cocsn-api/waveserver/restapi/operations/ciena_waveserver_interfaces"
)

//go:generate swagger generate server --target ../../waveserver --name Cocsn --spec ../ws-if.yml --principal interface{}

func configureFlags(api *operations.CocsnAPI) {
	// api.CommandLineOptionsGroups = []swag.CommandLineOptionsGroup{ ... }
}

func configureAPI(api *operations.CocsnAPI) http.Handler {
	// configure the api here
	api.ServeError = errors.ServeError

	// Set your custom logger if needed. Default one is log.Printf
	// Expected interface func(string, ...interface{})
	//
	// Example:
	// api.Logger = log.Printf

	api.UseSwaggerUI()
	// To continue using redoc as your UI, uncomment the following line
	// api.UseRedoc()

	api.JSONConsumer = runtime.JSONConsumer()

	api.JSONProducer = runtime.JSONProducer()

	if api.CienaWaveserverInterfacesDeleteDataWaveserverInterfacesHandler == nil {
		api.CienaWaveserverInterfacesDeleteDataWaveserverInterfacesHandler = ciena_waveserver_interfaces.DeleteDataWaveserverInterfacesHandlerFunc(func(params ciena_waveserver_interfaces.DeleteDataWaveserverInterfacesParams) middleware.Responder {
			return middleware.NotImplemented("operation ciena_waveserver_interfaces.DeleteDataWaveserverInterfaces has not yet been implemented")
		})
	}
	if api.CienaWaveserverInterfacesDeleteDataWaveserverInterfacesLogicalInterfaceIndexHandler == nil {
		api.CienaWaveserverInterfacesDeleteDataWaveserverInterfacesLogicalInterfaceIndexHandler = ciena_waveserver_interfaces.DeleteDataWaveserverInterfacesLogicalInterfaceIndexHandlerFunc(func(params ciena_waveserver_interfaces.DeleteDataWaveserverInterfacesLogicalInterfaceIndexParams) middleware.Responder {
			return middleware.NotImplemented("operation ciena_waveserver_interfaces.DeleteDataWaveserverInterfacesLogicalInterfaceIndex has not yet been implemented")
		})
	}
	if api.CienaWaveserverInterfacesDeleteDataWaveserverInterfacesLogicalInterfaceIndexIDHandler == nil {
		api.CienaWaveserverInterfacesDeleteDataWaveserverInterfacesLogicalInterfaceIndexIDHandler = ciena_waveserver_interfaces.DeleteDataWaveserverInterfacesLogicalInterfaceIndexIDHandlerFunc(func(params ciena_waveserver_interfaces.DeleteDataWaveserverInterfacesLogicalInterfaceIndexIDParams) middleware.Responder {
			return middleware.NotImplemented("operation ciena_waveserver_interfaces.DeleteDataWaveserverInterfacesLogicalInterfaceIndexID has not yet been implemented")
		})
	}
	if api.CienaWaveserverInterfacesDeleteDataWaveserverInterfacesLogicalInterfaceIndexPropertiesHandler == nil {
		api.CienaWaveserverInterfacesDeleteDataWaveserverInterfacesLogicalInterfaceIndexPropertiesHandler = ciena_waveserver_interfaces.DeleteDataWaveserverInterfacesLogicalInterfaceIndexPropertiesHandlerFunc(func(params ciena_waveserver_interfaces.DeleteDataWaveserverInterfacesLogicalInterfaceIndexPropertiesParams) middleware.Responder {
			return middleware.NotImplemented("operation ciena_waveserver_interfaces.DeleteDataWaveserverInterfacesLogicalInterfaceIndexProperties has not yet been implemented")
		})
	}
	if api.CienaWaveserverInterfacesDeleteDataWaveserverInterfacesLogicalInterfaceIndexPropertiesIPV4Handler == nil {
		api.CienaWaveserverInterfacesDeleteDataWaveserverInterfacesLogicalInterfaceIndexPropertiesIPV4Handler = ciena_waveserver_interfaces.DeleteDataWaveserverInterfacesLogicalInterfaceIndexPropertiesIPV4HandlerFunc(func(params ciena_waveserver_interfaces.DeleteDataWaveserverInterfacesLogicalInterfaceIndexPropertiesIPV4Params) middleware.Responder {
			return middleware.NotImplemented("operation ciena_waveserver_interfaces.DeleteDataWaveserverInterfacesLogicalInterfaceIndexPropertiesIPV4 has not yet been implemented")
		})
	}
	if api.CienaWaveserverInterfacesDeleteDataWaveserverInterfacesLogicalInterfaceIndexStateHandler == nil {
		api.CienaWaveserverInterfacesDeleteDataWaveserverInterfacesLogicalInterfaceIndexStateHandler = ciena_waveserver_interfaces.DeleteDataWaveserverInterfacesLogicalInterfaceIndexStateHandlerFunc(func(params ciena_waveserver_interfaces.DeleteDataWaveserverInterfacesLogicalInterfaceIndexStateParams) middleware.Responder {
			return middleware.NotImplemented("operation ciena_waveserver_interfaces.DeleteDataWaveserverInterfacesLogicalInterfaceIndexState has not yet been implemented")
		})
	}
	if api.CienaWaveserverInterfacesDeleteDataWaveserverInterfacesPhysicalInterfaceNameHandler == nil {
		api.CienaWaveserverInterfacesDeleteDataWaveserverInterfacesPhysicalInterfaceNameHandler = ciena_waveserver_interfaces.DeleteDataWaveserverInterfacesPhysicalInterfaceNameHandlerFunc(func(params ciena_waveserver_interfaces.DeleteDataWaveserverInterfacesPhysicalInterfaceNameParams) middleware.Responder {
			return middleware.NotImplemented("operation ciena_waveserver_interfaces.DeleteDataWaveserverInterfacesPhysicalInterfaceName has not yet been implemented")
		})
	}
	if api.CienaWaveserverInterfacesDeleteDataWaveserverInterfacesPhysicalInterfaceNameIDHandler == nil {
		api.CienaWaveserverInterfacesDeleteDataWaveserverInterfacesPhysicalInterfaceNameIDHandler = ciena_waveserver_interfaces.DeleteDataWaveserverInterfacesPhysicalInterfaceNameIDHandlerFunc(func(params ciena_waveserver_interfaces.DeleteDataWaveserverInterfacesPhysicalInterfaceNameIDParams) middleware.Responder {
			return middleware.NotImplemented("operation ciena_waveserver_interfaces.DeleteDataWaveserverInterfacesPhysicalInterfaceNameID has not yet been implemented")
		})
	}
	if api.CienaWaveserverInterfacesDeleteDataWaveserverInterfacesPhysicalInterfaceNamePropertiesHandler == nil {
		api.CienaWaveserverInterfacesDeleteDataWaveserverInterfacesPhysicalInterfaceNamePropertiesHandler = ciena_waveserver_interfaces.DeleteDataWaveserverInterfacesPhysicalInterfaceNamePropertiesHandlerFunc(func(params ciena_waveserver_interfaces.DeleteDataWaveserverInterfacesPhysicalInterfaceNamePropertiesParams) middleware.Responder {
			return middleware.NotImplemented("operation ciena_waveserver_interfaces.DeleteDataWaveserverInterfacesPhysicalInterfaceNameProperties has not yet been implemented")
		})
	}
	if api.CienaWaveserverInterfacesDeleteDataWaveserverInterfacesPhysicalInterfaceNamePropertiesEthernetHandler == nil {
		api.CienaWaveserverInterfacesDeleteDataWaveserverInterfacesPhysicalInterfaceNamePropertiesEthernetHandler = ciena_waveserver_interfaces.DeleteDataWaveserverInterfacesPhysicalInterfaceNamePropertiesEthernetHandlerFunc(func(params ciena_waveserver_interfaces.DeleteDataWaveserverInterfacesPhysicalInterfaceNamePropertiesEthernetParams) middleware.Responder {
			return middleware.NotImplemented("operation ciena_waveserver_interfaces.DeleteDataWaveserverInterfacesPhysicalInterfaceNamePropertiesEthernet has not yet been implemented")
		})
	}
	if api.CienaWaveserverInterfacesDeleteDataWaveserverInterfacesPhysicalInterfaceNamePropertiesManagementHandler == nil {
		api.CienaWaveserverInterfacesDeleteDataWaveserverInterfacesPhysicalInterfaceNamePropertiesManagementHandler = ciena_waveserver_interfaces.DeleteDataWaveserverInterfacesPhysicalInterfaceNamePropertiesManagementHandlerFunc(func(params ciena_waveserver_interfaces.DeleteDataWaveserverInterfacesPhysicalInterfaceNamePropertiesManagementParams) middleware.Responder {
			return middleware.NotImplemented("operation ciena_waveserver_interfaces.DeleteDataWaveserverInterfacesPhysicalInterfaceNamePropertiesManagement has not yet been implemented")
		})
	}
	if api.CienaWaveserverInterfacesDeleteDataWaveserverInterfacesPhysicalInterfaceNameStateHandler == nil {
		api.CienaWaveserverInterfacesDeleteDataWaveserverInterfacesPhysicalInterfaceNameStateHandler = ciena_waveserver_interfaces.DeleteDataWaveserverInterfacesPhysicalInterfaceNameStateHandlerFunc(func(params ciena_waveserver_interfaces.DeleteDataWaveserverInterfacesPhysicalInterfaceNameStateParams) middleware.Responder {
			return middleware.NotImplemented("operation ciena_waveserver_interfaces.DeleteDataWaveserverInterfacesPhysicalInterfaceNameState has not yet been implemented")
		})
	}
	if api.CienaWaveserverInterfacesDeleteDataWaveserverInterfacesRoutesHandler == nil {
		api.CienaWaveserverInterfacesDeleteDataWaveserverInterfacesRoutesHandler = ciena_waveserver_interfaces.DeleteDataWaveserverInterfacesRoutesHandlerFunc(func(params ciena_waveserver_interfaces.DeleteDataWaveserverInterfacesRoutesParams) middleware.Responder {
			return middleware.NotImplemented("operation ciena_waveserver_interfaces.DeleteDataWaveserverInterfacesRoutes has not yet been implemented")
		})
	}
	if api.CienaWaveserverInterfacesDeleteDataWaveserverInterfacesRoutesIPV4StaticRouteDestinationHandler == nil {
		api.CienaWaveserverInterfacesDeleteDataWaveserverInterfacesRoutesIPV4StaticRouteDestinationHandler = ciena_waveserver_interfaces.DeleteDataWaveserverInterfacesRoutesIPV4StaticRouteDestinationHandlerFunc(func(params ciena_waveserver_interfaces.DeleteDataWaveserverInterfacesRoutesIPV4StaticRouteDestinationParams) middleware.Responder {
			return middleware.NotImplemented("operation ciena_waveserver_interfaces.DeleteDataWaveserverInterfacesRoutesIPV4StaticRouteDestination has not yet been implemented")
		})
	}
	if api.CienaWaveserverInterfacesDeleteDataWaveserverInterfacesRoutesIPV4StaticRouteDestinationNextHopIndexHandler == nil {
		api.CienaWaveserverInterfacesDeleteDataWaveserverInterfacesRoutesIPV4StaticRouteDestinationNextHopIndexHandler = ciena_waveserver_interfaces.DeleteDataWaveserverInterfacesRoutesIPV4StaticRouteDestinationNextHopIndexHandlerFunc(func(params ciena_waveserver_interfaces.DeleteDataWaveserverInterfacesRoutesIPV4StaticRouteDestinationNextHopIndexParams) middleware.Responder {
			return middleware.NotImplemented("operation ciena_waveserver_interfaces.DeleteDataWaveserverInterfacesRoutesIPV4StaticRouteDestinationNextHopIndex has not yet been implemented")
		})
	}
	if api.CienaWaveserverInterfacesGetDataWaveserverInterfacesHandler == nil {
		api.CienaWaveserverInterfacesGetDataWaveserverInterfacesHandler = ciena_waveserver_interfaces.GetDataWaveserverInterfacesHandlerFunc(func(params ciena_waveserver_interfaces.GetDataWaveserverInterfacesParams) middleware.Responder {
			return middleware.NotImplemented("operation ciena_waveserver_interfaces.GetDataWaveserverInterfaces has not yet been implemented")
		})
	}
	if api.CienaWaveserverInterfacesGetDataWaveserverInterfacesLogicalInterfaceIndexHandler == nil {
		api.CienaWaveserverInterfacesGetDataWaveserverInterfacesLogicalInterfaceIndexHandler = ciena_waveserver_interfaces.GetDataWaveserverInterfacesLogicalInterfaceIndexHandlerFunc(func(params ciena_waveserver_interfaces.GetDataWaveserverInterfacesLogicalInterfaceIndexParams) middleware.Responder {
			return middleware.NotImplemented("operation ciena_waveserver_interfaces.GetDataWaveserverInterfacesLogicalInterfaceIndex has not yet been implemented")
		})
	}
	if api.CienaWaveserverInterfacesGetDataWaveserverInterfacesLogicalInterfaceIndexIDHandler == nil {
		api.CienaWaveserverInterfacesGetDataWaveserverInterfacesLogicalInterfaceIndexIDHandler = ciena_waveserver_interfaces.GetDataWaveserverInterfacesLogicalInterfaceIndexIDHandlerFunc(func(params ciena_waveserver_interfaces.GetDataWaveserverInterfacesLogicalInterfaceIndexIDParams) middleware.Responder {
			return middleware.NotImplemented("operation ciena_waveserver_interfaces.GetDataWaveserverInterfacesLogicalInterfaceIndexID has not yet been implemented")
		})
	}
	if api.CienaWaveserverInterfacesGetDataWaveserverInterfacesLogicalInterfaceIndexPropertiesHandler == nil {
		api.CienaWaveserverInterfacesGetDataWaveserverInterfacesLogicalInterfaceIndexPropertiesHandler = ciena_waveserver_interfaces.GetDataWaveserverInterfacesLogicalInterfaceIndexPropertiesHandlerFunc(func(params ciena_waveserver_interfaces.GetDataWaveserverInterfacesLogicalInterfaceIndexPropertiesParams) middleware.Responder {
			return middleware.NotImplemented("operation ciena_waveserver_interfaces.GetDataWaveserverInterfacesLogicalInterfaceIndexProperties has not yet been implemented")
		})
	}
	if api.CienaWaveserverInterfacesGetDataWaveserverInterfacesLogicalInterfaceIndexPropertiesIPV4Handler == nil {
		api.CienaWaveserverInterfacesGetDataWaveserverInterfacesLogicalInterfaceIndexPropertiesIPV4Handler = ciena_waveserver_interfaces.GetDataWaveserverInterfacesLogicalInterfaceIndexPropertiesIPV4HandlerFunc(func(params ciena_waveserver_interfaces.GetDataWaveserverInterfacesLogicalInterfaceIndexPropertiesIPV4Params) middleware.Responder {
			return middleware.NotImplemented("operation ciena_waveserver_interfaces.GetDataWaveserverInterfacesLogicalInterfaceIndexPropertiesIPV4 has not yet been implemented")
		})
	}
	if api.CienaWaveserverInterfacesGetDataWaveserverInterfacesLogicalInterfaceIndexStateHandler == nil {
		api.CienaWaveserverInterfacesGetDataWaveserverInterfacesLogicalInterfaceIndexStateHandler = ciena_waveserver_interfaces.GetDataWaveserverInterfacesLogicalInterfaceIndexStateHandlerFunc(func(params ciena_waveserver_interfaces.GetDataWaveserverInterfacesLogicalInterfaceIndexStateParams) middleware.Responder {
			return middleware.NotImplemented("operation ciena_waveserver_interfaces.GetDataWaveserverInterfacesLogicalInterfaceIndexState has not yet been implemented")
		})
	}
	if api.CienaWaveserverInterfacesGetDataWaveserverInterfacesPhysicalInterfaceNameHandler == nil {
		api.CienaWaveserverInterfacesGetDataWaveserverInterfacesPhysicalInterfaceNameHandler = ciena_waveserver_interfaces.GetDataWaveserverInterfacesPhysicalInterfaceNameHandlerFunc(func(params ciena_waveserver_interfaces.GetDataWaveserverInterfacesPhysicalInterfaceNameParams) middleware.Responder {
			return middleware.NotImplemented("operation ciena_waveserver_interfaces.GetDataWaveserverInterfacesPhysicalInterfaceName has not yet been implemented")
		})
	}
	if api.CienaWaveserverInterfacesGetDataWaveserverInterfacesPhysicalInterfaceNameIDHandler == nil {
		api.CienaWaveserverInterfacesGetDataWaveserverInterfacesPhysicalInterfaceNameIDHandler = ciena_waveserver_interfaces.GetDataWaveserverInterfacesPhysicalInterfaceNameIDHandlerFunc(func(params ciena_waveserver_interfaces.GetDataWaveserverInterfacesPhysicalInterfaceNameIDParams) middleware.Responder {
			return middleware.NotImplemented("operation ciena_waveserver_interfaces.GetDataWaveserverInterfacesPhysicalInterfaceNameID has not yet been implemented")
		})
	}
	if api.CienaWaveserverInterfacesGetDataWaveserverInterfacesPhysicalInterfaceNamePropertiesHandler == nil {
		api.CienaWaveserverInterfacesGetDataWaveserverInterfacesPhysicalInterfaceNamePropertiesHandler = ciena_waveserver_interfaces.GetDataWaveserverInterfacesPhysicalInterfaceNamePropertiesHandlerFunc(func(params ciena_waveserver_interfaces.GetDataWaveserverInterfacesPhysicalInterfaceNamePropertiesParams) middleware.Responder {
			return middleware.NotImplemented("operation ciena_waveserver_interfaces.GetDataWaveserverInterfacesPhysicalInterfaceNameProperties has not yet been implemented")
		})
	}
	if api.CienaWaveserverInterfacesGetDataWaveserverInterfacesPhysicalInterfaceNamePropertiesEthernetHandler == nil {
		api.CienaWaveserverInterfacesGetDataWaveserverInterfacesPhysicalInterfaceNamePropertiesEthernetHandler = ciena_waveserver_interfaces.GetDataWaveserverInterfacesPhysicalInterfaceNamePropertiesEthernetHandlerFunc(func(params ciena_waveserver_interfaces.GetDataWaveserverInterfacesPhysicalInterfaceNamePropertiesEthernetParams) middleware.Responder {
			return middleware.NotImplemented("operation ciena_waveserver_interfaces.GetDataWaveserverInterfacesPhysicalInterfaceNamePropertiesEthernet has not yet been implemented")
		})
	}
	if api.CienaWaveserverInterfacesGetDataWaveserverInterfacesPhysicalInterfaceNamePropertiesManagementHandler == nil {
		api.CienaWaveserverInterfacesGetDataWaveserverInterfacesPhysicalInterfaceNamePropertiesManagementHandler = ciena_waveserver_interfaces.GetDataWaveserverInterfacesPhysicalInterfaceNamePropertiesManagementHandlerFunc(func(params ciena_waveserver_interfaces.GetDataWaveserverInterfacesPhysicalInterfaceNamePropertiesManagementParams) middleware.Responder {
			return middleware.NotImplemented("operation ciena_waveserver_interfaces.GetDataWaveserverInterfacesPhysicalInterfaceNamePropertiesManagement has not yet been implemented")
		})
	}
	if api.CienaWaveserverInterfacesGetDataWaveserverInterfacesPhysicalInterfaceNameStateHandler == nil {
		api.CienaWaveserverInterfacesGetDataWaveserverInterfacesPhysicalInterfaceNameStateHandler = ciena_waveserver_interfaces.GetDataWaveserverInterfacesPhysicalInterfaceNameStateHandlerFunc(func(params ciena_waveserver_interfaces.GetDataWaveserverInterfacesPhysicalInterfaceNameStateParams) middleware.Responder {
			return middleware.NotImplemented("operation ciena_waveserver_interfaces.GetDataWaveserverInterfacesPhysicalInterfaceNameState has not yet been implemented")
		})
	}
	if api.CienaWaveserverInterfacesGetDataWaveserverInterfacesRoutesHandler == nil {
		api.CienaWaveserverInterfacesGetDataWaveserverInterfacesRoutesHandler = ciena_waveserver_interfaces.GetDataWaveserverInterfacesRoutesHandlerFunc(func(params ciena_waveserver_interfaces.GetDataWaveserverInterfacesRoutesParams) middleware.Responder {
			return middleware.NotImplemented("operation ciena_waveserver_interfaces.GetDataWaveserverInterfacesRoutes has not yet been implemented")
		})
	}
	if api.CienaWaveserverInterfacesGetDataWaveserverInterfacesRoutesIPV4StaticRouteDestinationHandler == nil {
		api.CienaWaveserverInterfacesGetDataWaveserverInterfacesRoutesIPV4StaticRouteDestinationHandler = ciena_waveserver_interfaces.GetDataWaveserverInterfacesRoutesIPV4StaticRouteDestinationHandlerFunc(func(params ciena_waveserver_interfaces.GetDataWaveserverInterfacesRoutesIPV4StaticRouteDestinationParams) middleware.Responder {
			return middleware.NotImplemented("operation ciena_waveserver_interfaces.GetDataWaveserverInterfacesRoutesIPV4StaticRouteDestination has not yet been implemented")
		})
	}
	if api.CienaWaveserverInterfacesGetDataWaveserverInterfacesRoutesIPV4StaticRouteDestinationNextHopIndexHandler == nil {
		api.CienaWaveserverInterfacesGetDataWaveserverInterfacesRoutesIPV4StaticRouteDestinationNextHopIndexHandler = ciena_waveserver_interfaces.GetDataWaveserverInterfacesRoutesIPV4StaticRouteDestinationNextHopIndexHandlerFunc(func(params ciena_waveserver_interfaces.GetDataWaveserverInterfacesRoutesIPV4StaticRouteDestinationNextHopIndexParams) middleware.Responder {
			return middleware.NotImplemented("operation ciena_waveserver_interfaces.GetDataWaveserverInterfacesRoutesIPV4StaticRouteDestinationNextHopIndex has not yet been implemented")
		})
	}
	if api.CienaWaveserverInterfacesPostDataWaveserverInterfacesHandler == nil {
		api.CienaWaveserverInterfacesPostDataWaveserverInterfacesHandler = ciena_waveserver_interfaces.PostDataWaveserverInterfacesHandlerFunc(func(params ciena_waveserver_interfaces.PostDataWaveserverInterfacesParams) middleware.Responder {
			return middleware.NotImplemented("operation ciena_waveserver_interfaces.PostDataWaveserverInterfaces has not yet been implemented")
		})
	}
	if api.CienaWaveserverInterfacesPostDataWaveserverInterfacesLogicalInterfaceHandler == nil {
		api.CienaWaveserverInterfacesPostDataWaveserverInterfacesLogicalInterfaceHandler = ciena_waveserver_interfaces.PostDataWaveserverInterfacesLogicalInterfaceHandlerFunc(func(params ciena_waveserver_interfaces.PostDataWaveserverInterfacesLogicalInterfaceParams) middleware.Responder {
			return middleware.NotImplemented("operation ciena_waveserver_interfaces.PostDataWaveserverInterfacesLogicalInterface has not yet been implemented")
		})
	}
	if api.CienaWaveserverInterfacesPostDataWaveserverInterfacesLogicalInterfaceIndexIDHandler == nil {
		api.CienaWaveserverInterfacesPostDataWaveserverInterfacesLogicalInterfaceIndexIDHandler = ciena_waveserver_interfaces.PostDataWaveserverInterfacesLogicalInterfaceIndexIDHandlerFunc(func(params ciena_waveserver_interfaces.PostDataWaveserverInterfacesLogicalInterfaceIndexIDParams) middleware.Responder {
			return middleware.NotImplemented("operation ciena_waveserver_interfaces.PostDataWaveserverInterfacesLogicalInterfaceIndexID has not yet been implemented")
		})
	}
	if api.CienaWaveserverInterfacesPostDataWaveserverInterfacesLogicalInterfaceIndexPropertiesHandler == nil {
		api.CienaWaveserverInterfacesPostDataWaveserverInterfacesLogicalInterfaceIndexPropertiesHandler = ciena_waveserver_interfaces.PostDataWaveserverInterfacesLogicalInterfaceIndexPropertiesHandlerFunc(func(params ciena_waveserver_interfaces.PostDataWaveserverInterfacesLogicalInterfaceIndexPropertiesParams) middleware.Responder {
			return middleware.NotImplemented("operation ciena_waveserver_interfaces.PostDataWaveserverInterfacesLogicalInterfaceIndexProperties has not yet been implemented")
		})
	}
	if api.CienaWaveserverInterfacesPostDataWaveserverInterfacesLogicalInterfaceIndexPropertiesIPV4Handler == nil {
		api.CienaWaveserverInterfacesPostDataWaveserverInterfacesLogicalInterfaceIndexPropertiesIPV4Handler = ciena_waveserver_interfaces.PostDataWaveserverInterfacesLogicalInterfaceIndexPropertiesIPV4HandlerFunc(func(params ciena_waveserver_interfaces.PostDataWaveserverInterfacesLogicalInterfaceIndexPropertiesIPV4Params) middleware.Responder {
			return middleware.NotImplemented("operation ciena_waveserver_interfaces.PostDataWaveserverInterfacesLogicalInterfaceIndexPropertiesIPV4 has not yet been implemented")
		})
	}
	if api.CienaWaveserverInterfacesPostDataWaveserverInterfacesLogicalInterfaceIndexStateHandler == nil {
		api.CienaWaveserverInterfacesPostDataWaveserverInterfacesLogicalInterfaceIndexStateHandler = ciena_waveserver_interfaces.PostDataWaveserverInterfacesLogicalInterfaceIndexStateHandlerFunc(func(params ciena_waveserver_interfaces.PostDataWaveserverInterfacesLogicalInterfaceIndexStateParams) middleware.Responder {
			return middleware.NotImplemented("operation ciena_waveserver_interfaces.PostDataWaveserverInterfacesLogicalInterfaceIndexState has not yet been implemented")
		})
	}
	if api.CienaWaveserverInterfacesPostDataWaveserverInterfacesPhysicalInterfaceHandler == nil {
		api.CienaWaveserverInterfacesPostDataWaveserverInterfacesPhysicalInterfaceHandler = ciena_waveserver_interfaces.PostDataWaveserverInterfacesPhysicalInterfaceHandlerFunc(func(params ciena_waveserver_interfaces.PostDataWaveserverInterfacesPhysicalInterfaceParams) middleware.Responder {
			return middleware.NotImplemented("operation ciena_waveserver_interfaces.PostDataWaveserverInterfacesPhysicalInterface has not yet been implemented")
		})
	}
	if api.CienaWaveserverInterfacesPostDataWaveserverInterfacesPhysicalInterfaceNameIDHandler == nil {
		api.CienaWaveserverInterfacesPostDataWaveserverInterfacesPhysicalInterfaceNameIDHandler = ciena_waveserver_interfaces.PostDataWaveserverInterfacesPhysicalInterfaceNameIDHandlerFunc(func(params ciena_waveserver_interfaces.PostDataWaveserverInterfacesPhysicalInterfaceNameIDParams) middleware.Responder {
			return middleware.NotImplemented("operation ciena_waveserver_interfaces.PostDataWaveserverInterfacesPhysicalInterfaceNameID has not yet been implemented")
		})
	}
	if api.CienaWaveserverInterfacesPostDataWaveserverInterfacesPhysicalInterfaceNamePropertiesHandler == nil {
		api.CienaWaveserverInterfacesPostDataWaveserverInterfacesPhysicalInterfaceNamePropertiesHandler = ciena_waveserver_interfaces.PostDataWaveserverInterfacesPhysicalInterfaceNamePropertiesHandlerFunc(func(params ciena_waveserver_interfaces.PostDataWaveserverInterfacesPhysicalInterfaceNamePropertiesParams) middleware.Responder {
			return middleware.NotImplemented("operation ciena_waveserver_interfaces.PostDataWaveserverInterfacesPhysicalInterfaceNameProperties has not yet been implemented")
		})
	}
	if api.CienaWaveserverInterfacesPostDataWaveserverInterfacesPhysicalInterfaceNamePropertiesEthernetHandler == nil {
		api.CienaWaveserverInterfacesPostDataWaveserverInterfacesPhysicalInterfaceNamePropertiesEthernetHandler = ciena_waveserver_interfaces.PostDataWaveserverInterfacesPhysicalInterfaceNamePropertiesEthernetHandlerFunc(func(params ciena_waveserver_interfaces.PostDataWaveserverInterfacesPhysicalInterfaceNamePropertiesEthernetParams) middleware.Responder {
			return middleware.NotImplemented("operation ciena_waveserver_interfaces.PostDataWaveserverInterfacesPhysicalInterfaceNamePropertiesEthernet has not yet been implemented")
		})
	}
	if api.CienaWaveserverInterfacesPostDataWaveserverInterfacesPhysicalInterfaceNamePropertiesManagementHandler == nil {
		api.CienaWaveserverInterfacesPostDataWaveserverInterfacesPhysicalInterfaceNamePropertiesManagementHandler = ciena_waveserver_interfaces.PostDataWaveserverInterfacesPhysicalInterfaceNamePropertiesManagementHandlerFunc(func(params ciena_waveserver_interfaces.PostDataWaveserverInterfacesPhysicalInterfaceNamePropertiesManagementParams) middleware.Responder {
			return middleware.NotImplemented("operation ciena_waveserver_interfaces.PostDataWaveserverInterfacesPhysicalInterfaceNamePropertiesManagement has not yet been implemented")
		})
	}
	if api.CienaWaveserverInterfacesPostDataWaveserverInterfacesPhysicalInterfaceNameStateHandler == nil {
		api.CienaWaveserverInterfacesPostDataWaveserverInterfacesPhysicalInterfaceNameStateHandler = ciena_waveserver_interfaces.PostDataWaveserverInterfacesPhysicalInterfaceNameStateHandlerFunc(func(params ciena_waveserver_interfaces.PostDataWaveserverInterfacesPhysicalInterfaceNameStateParams) middleware.Responder {
			return middleware.NotImplemented("operation ciena_waveserver_interfaces.PostDataWaveserverInterfacesPhysicalInterfaceNameState has not yet been implemented")
		})
	}
	if api.CienaWaveserverInterfacesPostDataWaveserverInterfacesRoutesHandler == nil {
		api.CienaWaveserverInterfacesPostDataWaveserverInterfacesRoutesHandler = ciena_waveserver_interfaces.PostDataWaveserverInterfacesRoutesHandlerFunc(func(params ciena_waveserver_interfaces.PostDataWaveserverInterfacesRoutesParams) middleware.Responder {
			return middleware.NotImplemented("operation ciena_waveserver_interfaces.PostDataWaveserverInterfacesRoutes has not yet been implemented")
		})
	}
	if api.CienaWaveserverInterfacesPostDataWaveserverInterfacesRoutesIPV4StaticRouteHandler == nil {
		api.CienaWaveserverInterfacesPostDataWaveserverInterfacesRoutesIPV4StaticRouteHandler = ciena_waveserver_interfaces.PostDataWaveserverInterfacesRoutesIPV4StaticRouteHandlerFunc(func(params ciena_waveserver_interfaces.PostDataWaveserverInterfacesRoutesIPV4StaticRouteParams) middleware.Responder {
			return middleware.NotImplemented("operation ciena_waveserver_interfaces.PostDataWaveserverInterfacesRoutesIPV4StaticRoute has not yet been implemented")
		})
	}
	if api.CienaWaveserverInterfacesPostDataWaveserverInterfacesRoutesIPV4StaticRouteDestinationNextHopHandler == nil {
		api.CienaWaveserverInterfacesPostDataWaveserverInterfacesRoutesIPV4StaticRouteDestinationNextHopHandler = ciena_waveserver_interfaces.PostDataWaveserverInterfacesRoutesIPV4StaticRouteDestinationNextHopHandlerFunc(func(params ciena_waveserver_interfaces.PostDataWaveserverInterfacesRoutesIPV4StaticRouteDestinationNextHopParams) middleware.Responder {
			return middleware.NotImplemented("operation ciena_waveserver_interfaces.PostDataWaveserverInterfacesRoutesIPV4StaticRouteDestinationNextHop has not yet been implemented")
		})
	}
	if api.CienaWaveserverInterfacesPutDataWaveserverInterfacesHandler == nil {
		api.CienaWaveserverInterfacesPutDataWaveserverInterfacesHandler = ciena_waveserver_interfaces.PutDataWaveserverInterfacesHandlerFunc(func(params ciena_waveserver_interfaces.PutDataWaveserverInterfacesParams) middleware.Responder {
			return middleware.NotImplemented("operation ciena_waveserver_interfaces.PutDataWaveserverInterfaces has not yet been implemented")
		})
	}
	if api.CienaWaveserverInterfacesPutDataWaveserverInterfacesLogicalInterfaceIndexHandler == nil {
		api.CienaWaveserverInterfacesPutDataWaveserverInterfacesLogicalInterfaceIndexHandler = ciena_waveserver_interfaces.PutDataWaveserverInterfacesLogicalInterfaceIndexHandlerFunc(func(params ciena_waveserver_interfaces.PutDataWaveserverInterfacesLogicalInterfaceIndexParams) middleware.Responder {
			return middleware.NotImplemented("operation ciena_waveserver_interfaces.PutDataWaveserverInterfacesLogicalInterfaceIndex has not yet been implemented")
		})
	}
	if api.CienaWaveserverInterfacesPutDataWaveserverInterfacesLogicalInterfaceIndexIDHandler == nil {
		api.CienaWaveserverInterfacesPutDataWaveserverInterfacesLogicalInterfaceIndexIDHandler = ciena_waveserver_interfaces.PutDataWaveserverInterfacesLogicalInterfaceIndexIDHandlerFunc(func(params ciena_waveserver_interfaces.PutDataWaveserverInterfacesLogicalInterfaceIndexIDParams) middleware.Responder {
			return middleware.NotImplemented("operation ciena_waveserver_interfaces.PutDataWaveserverInterfacesLogicalInterfaceIndexID has not yet been implemented")
		})
	}
	if api.CienaWaveserverInterfacesPutDataWaveserverInterfacesLogicalInterfaceIndexPropertiesHandler == nil {
		api.CienaWaveserverInterfacesPutDataWaveserverInterfacesLogicalInterfaceIndexPropertiesHandler = ciena_waveserver_interfaces.PutDataWaveserverInterfacesLogicalInterfaceIndexPropertiesHandlerFunc(func(params ciena_waveserver_interfaces.PutDataWaveserverInterfacesLogicalInterfaceIndexPropertiesParams) middleware.Responder {
			return middleware.NotImplemented("operation ciena_waveserver_interfaces.PutDataWaveserverInterfacesLogicalInterfaceIndexProperties has not yet been implemented")
		})
	}
	if api.CienaWaveserverInterfacesPutDataWaveserverInterfacesLogicalInterfaceIndexPropertiesIPV4Handler == nil {
		api.CienaWaveserverInterfacesPutDataWaveserverInterfacesLogicalInterfaceIndexPropertiesIPV4Handler = ciena_waveserver_interfaces.PutDataWaveserverInterfacesLogicalInterfaceIndexPropertiesIPV4HandlerFunc(func(params ciena_waveserver_interfaces.PutDataWaveserverInterfacesLogicalInterfaceIndexPropertiesIPV4Params) middleware.Responder {
			return middleware.NotImplemented("operation ciena_waveserver_interfaces.PutDataWaveserverInterfacesLogicalInterfaceIndexPropertiesIPV4 has not yet been implemented")
		})
	}
	if api.CienaWaveserverInterfacesPutDataWaveserverInterfacesLogicalInterfaceIndexStateHandler == nil {
		api.CienaWaveserverInterfacesPutDataWaveserverInterfacesLogicalInterfaceIndexStateHandler = ciena_waveserver_interfaces.PutDataWaveserverInterfacesLogicalInterfaceIndexStateHandlerFunc(func(params ciena_waveserver_interfaces.PutDataWaveserverInterfacesLogicalInterfaceIndexStateParams) middleware.Responder {
			return middleware.NotImplemented("operation ciena_waveserver_interfaces.PutDataWaveserverInterfacesLogicalInterfaceIndexState has not yet been implemented")
		})
	}
	if api.CienaWaveserverInterfacesPutDataWaveserverInterfacesPhysicalInterfaceNameHandler == nil {
		api.CienaWaveserverInterfacesPutDataWaveserverInterfacesPhysicalInterfaceNameHandler = ciena_waveserver_interfaces.PutDataWaveserverInterfacesPhysicalInterfaceNameHandlerFunc(func(params ciena_waveserver_interfaces.PutDataWaveserverInterfacesPhysicalInterfaceNameParams) middleware.Responder {
			return middleware.NotImplemented("operation ciena_waveserver_interfaces.PutDataWaveserverInterfacesPhysicalInterfaceName has not yet been implemented")
		})
	}
	if api.CienaWaveserverInterfacesPutDataWaveserverInterfacesPhysicalInterfaceNameIDHandler == nil {
		api.CienaWaveserverInterfacesPutDataWaveserverInterfacesPhysicalInterfaceNameIDHandler = ciena_waveserver_interfaces.PutDataWaveserverInterfacesPhysicalInterfaceNameIDHandlerFunc(func(params ciena_waveserver_interfaces.PutDataWaveserverInterfacesPhysicalInterfaceNameIDParams) middleware.Responder {
			return middleware.NotImplemented("operation ciena_waveserver_interfaces.PutDataWaveserverInterfacesPhysicalInterfaceNameID has not yet been implemented")
		})
	}
	if api.CienaWaveserverInterfacesPutDataWaveserverInterfacesPhysicalInterfaceNamePropertiesHandler == nil {
		api.CienaWaveserverInterfacesPutDataWaveserverInterfacesPhysicalInterfaceNamePropertiesHandler = ciena_waveserver_interfaces.PutDataWaveserverInterfacesPhysicalInterfaceNamePropertiesHandlerFunc(func(params ciena_waveserver_interfaces.PutDataWaveserverInterfacesPhysicalInterfaceNamePropertiesParams) middleware.Responder {
			return middleware.NotImplemented("operation ciena_waveserver_interfaces.PutDataWaveserverInterfacesPhysicalInterfaceNameProperties has not yet been implemented")
		})
	}
	if api.CienaWaveserverInterfacesPutDataWaveserverInterfacesPhysicalInterfaceNamePropertiesEthernetHandler == nil {
		api.CienaWaveserverInterfacesPutDataWaveserverInterfacesPhysicalInterfaceNamePropertiesEthernetHandler = ciena_waveserver_interfaces.PutDataWaveserverInterfacesPhysicalInterfaceNamePropertiesEthernetHandlerFunc(func(params ciena_waveserver_interfaces.PutDataWaveserverInterfacesPhysicalInterfaceNamePropertiesEthernetParams) middleware.Responder {
			return middleware.NotImplemented("operation ciena_waveserver_interfaces.PutDataWaveserverInterfacesPhysicalInterfaceNamePropertiesEthernet has not yet been implemented")
		})
	}
	if api.CienaWaveserverInterfacesPutDataWaveserverInterfacesPhysicalInterfaceNamePropertiesManagementHandler == nil {
		api.CienaWaveserverInterfacesPutDataWaveserverInterfacesPhysicalInterfaceNamePropertiesManagementHandler = ciena_waveserver_interfaces.PutDataWaveserverInterfacesPhysicalInterfaceNamePropertiesManagementHandlerFunc(func(params ciena_waveserver_interfaces.PutDataWaveserverInterfacesPhysicalInterfaceNamePropertiesManagementParams) middleware.Responder {
			return middleware.NotImplemented("operation ciena_waveserver_interfaces.PutDataWaveserverInterfacesPhysicalInterfaceNamePropertiesManagement has not yet been implemented")
		})
	}
	if api.CienaWaveserverInterfacesPutDataWaveserverInterfacesPhysicalInterfaceNameStateHandler == nil {
		api.CienaWaveserverInterfacesPutDataWaveserverInterfacesPhysicalInterfaceNameStateHandler = ciena_waveserver_interfaces.PutDataWaveserverInterfacesPhysicalInterfaceNameStateHandlerFunc(func(params ciena_waveserver_interfaces.PutDataWaveserverInterfacesPhysicalInterfaceNameStateParams) middleware.Responder {
			return middleware.NotImplemented("operation ciena_waveserver_interfaces.PutDataWaveserverInterfacesPhysicalInterfaceNameState has not yet been implemented")
		})
	}
	if api.CienaWaveserverInterfacesPutDataWaveserverInterfacesRoutesHandler == nil {
		api.CienaWaveserverInterfacesPutDataWaveserverInterfacesRoutesHandler = ciena_waveserver_interfaces.PutDataWaveserverInterfacesRoutesHandlerFunc(func(params ciena_waveserver_interfaces.PutDataWaveserverInterfacesRoutesParams) middleware.Responder {
			return middleware.NotImplemented("operation ciena_waveserver_interfaces.PutDataWaveserverInterfacesRoutes has not yet been implemented")
		})
	}
	if api.CienaWaveserverInterfacesPutDataWaveserverInterfacesRoutesIPV4StaticRouteDestinationHandler == nil {
		api.CienaWaveserverInterfacesPutDataWaveserverInterfacesRoutesIPV4StaticRouteDestinationHandler = ciena_waveserver_interfaces.PutDataWaveserverInterfacesRoutesIPV4StaticRouteDestinationHandlerFunc(func(params ciena_waveserver_interfaces.PutDataWaveserverInterfacesRoutesIPV4StaticRouteDestinationParams) middleware.Responder {
			return middleware.NotImplemented("operation ciena_waveserver_interfaces.PutDataWaveserverInterfacesRoutesIPV4StaticRouteDestination has not yet been implemented")
		})
	}
	if api.CienaWaveserverInterfacesPutDataWaveserverInterfacesRoutesIPV4StaticRouteDestinationNextHopIndexHandler == nil {
		api.CienaWaveserverInterfacesPutDataWaveserverInterfacesRoutesIPV4StaticRouteDestinationNextHopIndexHandler = ciena_waveserver_interfaces.PutDataWaveserverInterfacesRoutesIPV4StaticRouteDestinationNextHopIndexHandlerFunc(func(params ciena_waveserver_interfaces.PutDataWaveserverInterfacesRoutesIPV4StaticRouteDestinationNextHopIndexParams) middleware.Responder {
			return middleware.NotImplemented("operation ciena_waveserver_interfaces.PutDataWaveserverInterfacesRoutesIPV4StaticRouteDestinationNextHopIndex has not yet been implemented")
		})
	}

	api.PreServerShutdown = func() {}

	api.ServerShutdown = func() {}

	return setupGlobalMiddleware(api.Serve(setupMiddlewares))
}

// The TLS configuration before HTTPS server starts.
func configureTLS(tlsConfig *tls.Config) {
	// Make all necessary changes to the TLS configuration here.
}

// As soon as server is initialized but not run yet, this function will be called.
// If you need to modify a config, store server instance to stop it individually later, this is the place.
// This function can be called multiple times, depending on the number of serving schemes.
// scheme value will be set accordingly: "http", "https" or "unix"
func configureServer(s *http.Server, scheme, addr string) {
}

// The middleware configuration is for the handler executors. These do not apply to the swagger.json document.
// The middleware executes after routing but before authentication, binding and validation
func setupMiddlewares(handler http.Handler) http.Handler {
	return handler
}

// The middleware configuration happens before anything, this middleware also applies to serving the swagger.json document.
// So this is a good place to plug in a panic handling middleware, logging and metrics
func setupGlobalMiddleware(handler http.Handler) http.Handler {
	return handler
}
